FramedMessage class

A complete payload reassembled by a framed channel.

Constructors

FramedMessage({required String channelId, required Uint8List payload})
Creates a framed-message event.
const

Properties

channelId String
Identifier returned by openFramedChannel.
final
hashCode int
The hash code for this object.
no setterinherited
payload Uint8List
Complete reassembled application payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited