ProtocolVersionRange class

An inclusive range of session protocol versions.

Constructors

ProtocolVersionRange(int minVersion, int maxVersion)
Creates a validated inclusive protocol range.

Properties

hashCode int
The hash code for this object.
no setterinherited
maxVersion int
Lowest and highest supported versions.
final
minVersion int
Lowest and highest supported versions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, int>
Encodes this range for the platform channel.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited