ScanProfile class

A protocol signature used to identify scan results.

Constructors

ScanProfile({required String id, List<String> serviceUuids = const [], List<String> namePrefixes = const [], List<int> manufacturerIds = const [], AdvertisementSignatureVerification? signatureVerification})
Creates and validates a scan profile.
ScanProfile.fromMap(Map<Object?, Object?> map)
Decodes and validates a platform-channel profile map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable application-defined identifier.
final
manufacturerIds List<int>
Bluetooth SIG manufacturer identifiers that identify this protocol.
final
namePrefixes List<String>
Advertised-name prefixes that identify this protocol.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceUuids List<String>
Advertised service UUIDs that identify this protocol. If all condition lists are empty, this profile explicitly matches every device.
final
signatureVerification AdvertisementSignatureVerification?
Optional Dart-side signed-advertisement verification contract.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Encodes this profile for a platform channel.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited