SecureDeviceHello class

Device's authenticated response and reciprocal challenge.

Constructors

SecureDeviceHello({required Uint8List deviceNonce, required Uint8List deviceChallenge, required Uint8List clientChallengeResponse, required SecureCipherSuite selectedSuite})
SecureDeviceHello.fromMap(Map<Object?, Object?> map)
factory

Properties

clientChallengeResponse Uint8List
final
deviceChallenge Uint8List
final
deviceNonce Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedSuite SecureCipherSuite
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited