SecurityTier enum

Device security capability advertised during session-open.

This describes capability only. Session-open does not establish encryption; P2 can establish an authenticated encrypted channel for symmetric devices.

Inheritance
Available extensions

Values

none → const SecurityTier
symmetric → const SecurityTier
asymmetric → const SecurityTier

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SecurityTier>
A constant List of the values in this enum, in order of their declaration.