BleLinkKitException class
Exception returned by a native Bluetooth operation.
- Implemented types
- Implementers
Constructors
- BleLinkKitException(BleErrorCode code, String message, [Object? details])
-
Creates an exception with a stable
codeand diagnosticmessage.const
Properties
- code → BleErrorCode
-
Machine-readable failure category.
final
- details → Object?
-
Optional platform details.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable diagnostic message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited